==> rax-webpack-plugin-0.0.6.tgz: package/lib/__test__/TraverseImport.test.js <==
'use strict';

var _TraverseImport = require('../TraverseImport');

var _TraverseImport2 = _interopRequireDefault(_TraverseImport);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('PlatformLoader.traverseImport', function () {
  it('isWeex true ', function () {
    var _traverseImport = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'weex' }, 'import { isWeex } from "universal-env";'),
        code = _traverseImport.code;

    expect(code).toBe('const isWeex = true;');
  });

  it('isWeex as iw ', function () {
    var _traverseImport2 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'weex' }, 'import { isWeex as iw } from "universal-env";'),
        code = _traverseImport2.code;

    expect(code).toBe('const iw = true;\nconst isWeex = true;');
  });

  it('isWeex and isWeb', function () {
    var _traverseImport3 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'weex' }, 'import { isWeex, isWeb } from "universal-env";'),
        code = _traverseImport3.code;

    expect(code).toBe('const isWeb = false;\nconst isWeex = true;');
  });

  it('isWeb true', function () {
    var _traverseImport4 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'web' }, 'import { isWeb } from "universal-env";'),
        code = _traverseImport4.code;

    expect(code).toBe('const isWeb = true;');
  });

  it('skin other module', function () {
    var _traverseImport5 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'web' }, 'import { isWeb } from "universal-env";\nimport { XXX } from "universal-other";\n'),
        code = _traverseImport5.code;

    expect(code).toBe('const isWeb = true;\n\nimport { XXX } from "universal-other?platform=web";');
  });

  it('not platform specified', function () {
    var _traverseImport6 = (0, _TraverseImport2.default)({ name: 'universal-env' }, 'import { isWeex, isWeb } from "universal-env";'),
        code = _traverseImport6.code;

    expect(code).toBe('import { isWeex, isWeb } from "universal-env";');
  });

  it('unkonw platform', function () {
    var _traverseImport7 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'xxxx' }, 'import { isWeex, isWeb } from "universal-env";'),
        code = _traverseImport7.code;

    expect(code).toBe('import { isWeex, isWeb } from "universal-env";');
  });

  it('unkonw platform and unkonw name', function () {
    var _traverseImport8 = (0, _TraverseImport2.default)({ name: 'universal-xxx' }, 'import { isWeex, isWeb } from "universal-env";'),
        code = _traverseImport8.code;

    expect(code).toBe('import { isWeex, isWeb } from "universal-env";');
  });
});

==> rax-webpack-plugin-0.0.7.tgz: package/lib/__test__/TraverseImport.test.js <==
'use strict';

var _TraverseImport = require('../TraverseImport');

var _TraverseImport2 = _interopRequireDefault(_TraverseImport);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('PlatformLoader.traverseImport', function () {
  it('isWeex true ', function () {
    var _traverseImport = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'weex' }, 'import { isWeex } from "universal-env";'),
        code = _traverseImport.code;

    expect(code).toBe('const isWeex = true;');
  });

  it('isWeex as iw ', function () {
    var _traverseImport2 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'weex' }, 'import { isWeex as iw } from "universal-env";'),
        code = _traverseImport2.code;

    expect(code).toBe('const iw = true;\nconst isWeex = true;');
  });

  it('isWeex and isWeb', function () {
    var _traverseImport3 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'weex' }, 'import { isWeex, isWeb } from "universal-env";'),
        code = _traverseImport3.code;

    expect(code).toBe('const isWeb = false;\nconst isWeex = true;');
  });

  it('isWeb true', function () {
    var _traverseImport4 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'web' }, 'import { isWeb } from "universal-env";'),
        code = _traverseImport4.code;

    expect(code).toBe('const isWeb = true;');
  });

  it('skin other module', function () {
    var _traverseImport5 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'web' }, 'import { isWeb } from "universal-env";\nimport { XXX } from "universal-other";\n'),
        code = _traverseImport5.code;

    expect(code).toBe('const isWeb = true;\n\nimport { XXX } from "universal-other";');
  });

  it('not platform specified', function () {
    var _traverseImport6 = (0, _TraverseImport2.default)({ name: 'universal-env' }, 'import { isWeex, isWeb } from "universal-env";'),
        code = _traverseImport6.code;

    expect(code).toBe('import { isWeex, isWeb } from "universal-env";');
  });

  it('unknown platform', function () {
    var _traverseImport7 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'xxxx' }, 'import { isWeex, isWeb } from "universal-env";'),
        code = _traverseImport7.code;

    expect(code).toBe('import { isWeex, isWeb } from "universal-env";');
  });

  it('unknown platform and unknown name', function () {
    var _traverseImport8 = (0, _TraverseImport2.default)({ name: 'universal-xxx' }, 'import { isWeex, isWeb } from "universal-env";'),
        code = _traverseImport8.code;

    expect(code).toBe('import { isWeex, isWeb } from "universal-env";');
  });
});
